use std::error::Error;

use bevy_ecs::world::World;
use vulkano::sync::GpuFuture;

use crate::core::app::context::WindowContext;

pub mod manager;

pub trait Scene {
    fn loaded(&self) -> bool;
    fn load(
        &mut self,
        world: &mut World,
        window_context: &mut WindowContext,
    ) -> Result<(), Box<dyn Error>>;
    fn update(
        &mut self,
        world: &mut World,
        window_context: &WindowContext,
    ) -> Result<(), Box<dyn Error>>;
    fn render(
        &mut self,
        acquire_future: Box<dyn GpuFuture>,
        world: &mut World,
        window_context: &mut WindowContext,
    ) -> Result<Box<dyn GpuFuture>, Box<dyn Error>>;
    fn unload(&mut self);
}
